@@ -23,12 +23,18 @@ FAILEDOPERATION_APPLICATIONCREATEESATUHERROR = 'FailedOperation.ApplicationCreat
 # 应用查询失败。
 FAILEDOPERATION_APPLICATIONQUERYFAILED = 'FailedOperation.ApplicationQueryFailed'
 
+# TSF云API请求调用失败。
+FAILEDOPERATION_CLOUDAPIPROXYERROR = 'FailedOperation.CloudApiProxyError'
+
 # 创建集群，开通VPC网络权限失败。
 FAILEDOPERATION_CLUSTERCREATEVPCFAIL = 'FailedOperation.ClusterCreateVpcFail'
 
 # 查询集群失败。
 FAILEDOPERATION_CLUSTERQUERYFAILED = 'FailedOperation.ClusterQueryFailed'
 
+# 更新集群失败。
+FAILEDOPERATION_CLUSTERUPDATEFAILED = 'FailedOperation.ClusterUpdateFailed'
+
 # 应用查询失败。
 FAILEDOPERATION_CONFIGAPPLICATIONQUERYFAILED = 'FailedOperation.ConfigApplicationQueryFailed'
 
@@ -47,12 +53,36 @@ FAILEDOPERATION_CONFIGQUERYFAILED = 'FailedOperation.ConfigQueryFailed'
 # 配置项发布信息查询失败。
 FAILEDOPERATION_CONFIGRELEASEQUERYFAILED = 'FailedOperation.ConfigReleaseQueryFailed'
 
+# 配置模板创建失败。
+FAILEDOPERATION_CONFIGTEMPLATECREATEFAILED = 'FailedOperation.ConfigTemplateCreateFailed'
+
+# 配置模板删除失败。
+FAILEDOPERATION_CONFIGTEMPLATEDELETEFAILED = 'FailedOperation.ConfigTemplateDeleteFailed'
+
+# 配置模板导入失败。
+FAILEDOPERATION_CONFIGTEMPLATEIMPORTFAILED = 'FailedOperation.ConfigTemplateImportFailed'
+
+# 配置模板分页查询失败。
+FAILEDOPERATION_CONFIGTEMPLATESEARCHLISTFAILED = 'FailedOperation.ConfigTemplateSearchListFailed'
+
+# 配置模板更新失败。
+FAILEDOPERATION_CONFIGTEMPLATEUPDATEFAILED = 'FailedOperation.ConfigTemplateUpdateFailed'
+
 # 部署组处于运行状态，无法启动。
 FAILEDOPERATION_CONTAINERGROUPGROUPHASRUN = 'FailedOperation.ContainergroupGroupHasrun'
 
 # 部署组处于停止状态，无法执行此操作。
 FAILEDOPERATION_CONTAINERGROUPGROUPHASSTOP = 'FailedOperation.ContainergroupGroupHasstop'
 
+# 调用 kube-api-server 失败。
+FAILEDOPERATION_CONTAINERGROUPKUBERNETEAPIINVOKEERROR = 'FailedOperation.ContainergroupKuberneteApiInvokeError'
+
+# 连接 kube-api-sever 失败。
+FAILEDOPERATION_CONTAINERGROUPKUBERNETECONNECTERROR = 'FailedOperation.ContainergroupKuberneteConnectError'
+
+# 调用 kube-api-server 失败。
+FAILEDOPERATION_CONTAINERGROUPKUBERNETESCONNECTERROR = 'FailedOperation.ContainergroupKubernetesConnectError'
+
 # 健康检查配置失败。
 FAILEDOPERATION_CVMCAEMASTERHEALTHCHECKCONFIGERROR = 'FailedOperation.CvmCaeMasterHealthCheckConfigError'
 
@@ -65,6 +95,9 @@ FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'
 # 部署组查询失败。
 FAILEDOPERATION_GROUPQUERYFAILD = 'FailedOperation.GroupQueryFaild'
 
+# tcr仓库绑定失败。
+FAILEDOPERATION_IMAGEREPOTCRBINDERROR = 'FailedOperation.ImagerepoTcrBindError'
+
 # 机器实例删除失败。
 FAILEDOPERATION_INSTANCEDELETEFAILED = 'FailedOperation.InstanceDeleteFailed'
 
@@ -80,6 +113,12 @@ FAILEDOPERATION_INSTANCERESETTIMEOUT = 'FailedOperation.InstanceResetTimeout'
 # 机器实例更新失败。
 FAILEDOPERATION_INSTANCEUPDATEFAILED = 'FailedOperation.InstanceUpdateFailed'
 
+# 内部错误。
+FAILEDOPERATION_INTERNALERROR = 'FailedOperation.InternalError'
+
+# 非法参数。
+FAILEDOPERATION_INVALIDPARAMETER = 'FailedOperation.InvalidParameter'
+
 # 泳道从consul删除失败。
 FAILEDOPERATION_LANEINFODELETECONSULFAILED = 'FailedOperation.LaneInfoDeleteConsulFailed'
 
@@ -107,6 +146,21 @@ FAILEDOPERATION_NAMESPACEQUERYFAILED = 'FailedOperation.NamespaceQueryFailed'
 # 访问配置中心失败。
 FAILEDOPERATION_RATELIMITCONSULERROR = 'FailedOperation.RatelimitConsulError'
 
+# 调用 Mesh API Server 失败。
+FAILEDOPERATION_RATELIMITMESHAPISERVICEERROR = 'FailedOperation.RatelimitMeshApiServiceError'
+
+# 资源操作失败。
+FAILEDOPERATION_RESOURCEOPFAILED = 'FailedOperation.ResourceOpFailed'
+
+# 路由就近访问策略启停用调用MESHAPI失败。
+FAILEDOPERATION_ROUTEAFFINITYMESHFAILED = 'FailedOperation.RouteAffinityMeshFailed'
+
+# 服务路由规则启用生效失败。
+FAILEDOPERATION_ROUTEENABLECONSULFAILED = 'FailedOperation.RouteEnableConsulFailed'
+
+# 路由就近访问，查询命名空间失败。
+FAILEDOPERATION_ROUTENAMESPACEREQUESTERROR = 'FailedOperation.RouteNamespaceRequestError'
+
 # 服务数据库入库失败。
 FAILEDOPERATION_SERVICEINSERTFAILED = 'FailedOperation.ServiceInsertFailed'
 
@@ -140,21 +194,81 @@ FAILEDOPERATION_TASKUPDATEERROR = 'FailedOperation.TaskUpdateError'
 # TKE 集群创建失败，%s。
 FAILEDOPERATION_TKECLUSTERCREATEFAILED = 'FailedOperation.TkeClusterCreateFailed'
 
+# TKE 集群删除失败。
+FAILEDOPERATION_TKECLUSTERDELETEFAILED = 'FailedOperation.TkeClusterDeleteFailed'
+
 # TKE 集群查询失败。
 FAILEDOPERATION_TKECLUSTERQUERYFAILED = 'FailedOperation.TkeClusterQueryFailed'
 
+# TSF应用性能管理任务数据库查询失败。
+FAILEDOPERATION_TSFAPMAGENTTASKQUERYERROR = 'FailedOperation.TsfApmAgentTaskQueryError'
+
+# TSF应用性能管理任务数据库写入失败。
+FAILEDOPERATION_TSFAPMAGENTTASKWRITEERROR = 'FailedOperation.TsfApmAgentTaskWriteError'
+
+# TSF应用性能管理apm-agent无法与该实例建立连接。
+FAILEDOPERATION_TSFAPMAPMAGENTNOCONNECTION = 'FailedOperation.TsfApmApmAgentNoConnection'
+
+# TSF应用性能管理业务日志配置与应用关联数据库写入失败。
+FAILEDOPERATION_TSFAPMBUSILOGCFGAPPRELATIONWRITEERROR = 'FailedOperation.TsfApmBusiLogCfgAppRelationWriteError'
+
+# TSF应用性能管理业务日志配置数据库查询失败。
+FAILEDOPERATION_TSFAPMBUSILOGCFGQUERYERROR = 'FailedOperation.TsfApmBusiLogCfgQueryError'
+
+# TSF应用性能管理业务日志配置解析规则查询失败。
+FAILEDOPERATION_TSFAPMBUSILOGCFGSCHEMAQUERYERROR = 'FailedOperation.TsfApmBusiLogCfgSchemaQueryError'
+
+# TSF应用性能管理业务日志配置解析规则写入失败。
+FAILEDOPERATION_TSFAPMBUSILOGCFGSCHEMAWRITEERROR = 'FailedOperation.TsfApmBusiLogCfgSchemaWriteError'
+
+# TSF应用性能管理业务日志配置数据库写入失败。
+FAILEDOPERATION_TSFAPMBUSILOGCFGWRITEERROR = 'FailedOperation.TsfApmBusiLogCfgWriteError'
+
+# 调用master接口更新部署组失败。
+FAILEDOPERATION_TSFAPMCALLMASTERINTERFACEFAILED = 'FailedOperation.TsfApmCallMasterInterfaceFailed'
+
+# TSF应用性能管理调用tsf-ms模块失败。
+FAILEDOPERATION_TSFAPMCALLTSFMSFAILED = 'FailedOperation.TsfApmCallTsfMsFailed'
+
 # TSF应用性能管理CTSDB客户端调用失败。
 FAILEDOPERATION_TSFAPMCTSDBCLIENTREQUESTERROR = 'FailedOperation.TsfApmCtsdbClientRequestError'
 
+# TSF应用性能管理内部异常, 请稍后重试。
+FAILEDOPERATION_TSFAPMINTERNALERROR = 'FailedOperation.TsfApmInternalError'
+
+# TSF应用性能管理运行状态统计查询服务查询失败。
+FAILEDOPERATION_TSFAPMSTATSSEARCHSERVICEQUERYERROR = 'FailedOperation.TsfApmStatsSearchServiceQueryError'
+
+# 数据库插入规则失败。
+FAILEDOPERATION_TSFASDBINSTERFAIL = 'FailedOperation.TsfAsDbInsterFail'
+
+# 查询数据库失败。
+FAILEDOPERATION_TSFASDBQUERYFAIL = 'FailedOperation.TsfAsDbQueryFail'
+
+# 扩容规则每次扩容机器数目不能大于机器最大数目。
+FAILEDOPERATION_TSFASEXPANDCOUNTANDLIMITERROR = 'FailedOperation.TsfAsExpandCountAndLimitError'
+
+# 扩容规则指标不能小于缩容规则。
+FAILEDOPERATION_TSFASEXPANDINDICATORSLESSSHRINK = 'FailedOperation.TsfAsExpandIndicatorsLessShrink'
+
+# 扩容最大实例数不能小于缩容最小实例数。
+FAILEDOPERATION_TSFASEXPANDLIMITLESSSHRINKLIMIT = 'FailedOperation.TsfAsExpandLimitLessShrinkLimit'
+
 # ctsdb数据库请求失败。
 FAILEDOPERATION_TSFCMONITORCTSDBCLIENTREQUESTFAIL = 'FailedOperation.TsfCmonitorCtsdbClientRequestFail'
 
 # TSF监控统计等待超时, 请稍后重试。
 FAILEDOPERATION_TSFMONITORWAITEDTIMEOUT = 'FailedOperation.TsfMonitorWaitedTimeout'
 
+# 调用ms server失败。
+FAILEDOPERATION_TSFMSSERVERERROR = 'FailedOperation.TsfMsServerError'
+
 # TSF权限模块异常，请联系系统管理员。。
 FAILEDOPERATION_TSFPRIVILEGEERROR = 'FailedOperation.TsfPrivilegeError'
 
+# 未授权。
+FAILEDOPERATION_UNAUTHORIZEDOPERATION = 'FailedOperation.UnauthorizedOperation'
+
 # 模块未处理异常。
 FAILEDOPERATION_UNHANDLEDEXCEPTION = 'FailedOperation.UnhandledException'
 
@@ -173,6 +287,9 @@ INTERNALERROR_APPLICATIONSCALABLEINITERROR = 'InternalError.ApplicationScalableI
 # TSF云API调用申请角色临时凭证调用请求失败。
 INTERNALERROR_CAMROLEREQUESTERROR = 'InternalError.CamRoleRequestError'
 
+# 配置发布失败：无法连接配置中心服务器。
+INTERNALERROR_CANNOTCONNCONSULSERVER = 'InternalError.CanNotConnConsulServer'
+
 # TSF云API请求调用失败。
 INTERNALERROR_CLOUDAPIPROXYERROR = 'InternalError.CloudApiProxyError'
 
@@ -212,6 +329,9 @@ INTERNALERROR_CVMCAEMASTERINTERNALERROR = 'InternalError.CvmCaeMasterInternalErr
 # MASTER通道查询失败。
 INTERNALERROR_CVMCAEMASTERNONALIVE = 'InternalError.CvmCaeMasterNonAlive'
 
+# TSF暂时不能响应请求。。
+INTERNALERROR_DISPATCHCOMMONERROR = 'InternalError.DispatchCommonError'
+
 # 网关通用异常:%s。
 INTERNALERROR_GATEWAYCOMMONERROR = 'InternalError.GatewayCommonError'
 
@@ -239,7 +359,7 @@ INTERNALERROR_INSTANCECOMMONERROR = 'InternalError.InstanceCommonError'
 # 创建kubernetes命名空间失败。
 INTERNALERROR_KUBERNETESAPICREATENAMESPACESERROR = 'InternalError.KubernetesApiCreateNamespacesError'
 
-# 创建kubernetes秘钥失败。
+# 创建kubernetes密钥失败。
 INTERNALERROR_KUBERNETESAPICREATESECRETERROR = 'InternalError.KubernetesApiCreateSecretError'
 
 # kubernetes api 调用失败。
@@ -260,6 +380,15 @@ INTERNALERROR_TASKINTERNALERROR = 'InternalError.TaskInternalError'
 # 调用 TKE 接口失败，%s。
 INTERNALERROR_TKEAPIFAILEDOPERATION = 'InternalError.TkeApiFailedOperation'
 
+# TSF应用性能管理业务日志配置与应用关联处理错误。
+INTERNALERROR_TSFAPMBUSILOGCFGAPPRELATIONMASTERERROR = 'InternalError.TsfApmBusiLogCfgAppRelationMasterError'
+
+# TSF应用性能管理调用tsf-ms模块失败。
+INTERNALERROR_TSFAPMCALLTSFMSFAILED = 'InternalError.TsfApmCallTsfMsFailed'
+
+# TSF应用性能管理通用异常。
+INTERNALERROR_TSFAPMCOMMONERROR = 'InternalError.TsfApmCommonError'
+
 # TSF应用性能管理ES客户端响应状态异常。
 INTERNALERROR_TSFAPMESRESPONSESTATUSEXCEPTION = 'InternalError.TsfApmEsResponseStatusException'
 
@@ -278,9 +407,15 @@ INTERNALERROR_UNHANDLEDEXCEPTION = 'InternalError.UnhandledException'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 删除应用失败。
+INVALIDPARAMETER_APPLICATIONDELETEFAILED = 'InvalidParameter.ApplicationDeleteFailed'
+
 # [%s]模块接口[%s]请求不正确（400 BAD REQUEST）。。
 INVALIDPARAMETER_BADREQUEST = 'InvalidParameter.BadRequest'
 
+# 配置模板名称不符合规范。
+INVALIDPARAMETER_CONFIGTEMPLATENAMEINVALID = 'InvalidParameter.ConfigTemplateNameInvalid'
+
 # TSF MASTER 实例状态异常。
 INVALIDPARAMETER_CVMCAEMASTERUNKNOWNINSTANCESTATUS = 'InvalidParameter.CvmCaeMasterUnknownInstanceStatus'
 
@@ -362,9 +497,21 @@ INVALIDPARAMETER_REPOPACKAGEPARAMERROR = 'InvalidParameter.RepoPackageParamError
 # 仓库中存在软件包，请先删除软件包。
 INVALIDPARAMETER_REPOSITORYNOTEMPTY = 'InvalidParameter.RepositoryNotEmpty'
 
+# TSF应用性能管理业务日志应用标识参数错误。
+INVALIDPARAMETER_TSFAPMBUSILOGCFGAPPPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgAppParamError'
+
 # TSF应用性能管理业务日志配置与应用关联参数错误。
 INVALIDPARAMETER_TSFAPMBUSILOGCFGAPPRELATIONPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgAppRelationParamError'
 
+# TSF应用性能管理业务日志配置云账户参数错误。
+INVALIDPARAMETER_TSFAPMBUSILOGCFGCLOUDPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgCloudParamError'
+
+# TSF应用性能管理业务日志配置标识参数错误。
+INVALIDPARAMETER_TSFAPMBUSILOGCFGIDPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgIdParamError'
+
+# TSF应用性能管理业务日志配置数目参数错误。
+INVALIDPARAMETER_TSFAPMBUSILOGCFGLIMITPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgLimitParamError'
+
 # TSF应用性能管理业务日志搜索请求参数错误。
 INVALIDPARAMETER_TSFAPMBUSILOGSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmBusiLogSearchRequestParamError'
 
@@ -386,12 +533,18 @@ INVALIDPARAMETER_UPPERDELETELIMIT = 'InvalidParameter.UpperDeleteLimit'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 应用描述不能大于200组字符。
+INVALIDPARAMETERVALUE_APPLICATIONDESCLENGTH = 'InvalidParameterValue.ApplicationDescLength'
+
 # 无效的微服务类型。
 INVALIDPARAMETERVALUE_APPLICATIONMICROTYPEINVALID = 'InvalidParameterValue.ApplicationMicroTypeInvalid'
 
 # 应用名称已存在，请更换其他名称。
 INVALIDPARAMETERVALUE_APPLICATIONNAMEEXIST = 'InvalidParameterValue.ApplicationNameExist'
 
+# 应用名称不能大于60字符。
+INVALIDPARAMETERVALUE_APPLICATIONNAMELENGTH = 'InvalidParameterValue.ApplicationNameLength'
+
 # 应用名称不能为空。
 INVALIDPARAMETERVALUE_APPLICATIONNAMENULL = 'InvalidParameterValue.ApplicationNameNull'
 
@@ -443,6 +596,18 @@ INVALIDPARAMETERVALUE_CONFIGNOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValue
 # 无法获取配置项发布信息。
 INVALIDPARAMETERVALUE_CONFIGRELEASENOTEXISTS = 'InvalidParameterValue.ConfigReleaseNotExists'
 
+# 配置模板描述过长。
+INVALIDPARAMETERVALUE_CONFIGTEMPLATEDESCTOOLONG = 'InvalidParameterValue.ConfigTemplateDescTooLong'
+
+# 配置模板名称不合规。
+INVALIDPARAMETERVALUE_CONFIGTEMPLATENAMEINVALID = 'InvalidParameterValue.ConfigTemplateNameInvalid'
+
+# 配置模板内容过长。
+INVALIDPARAMETERVALUE_CONFIGTEMPLATENAMETOOLONG = 'InvalidParameterValue.ConfigTemplateNameTooLong'
+
+# 配置模板类型不合规。
+INVALIDPARAMETERVALUE_CONFIGTEMPLATETYPEINVALID = 'InvalidParameterValue.ConfigTemplateTypeInvalid'
+
 # 配置格式不符合YAML要求。
 INVALIDPARAMETERVALUE_CONFIGVALUEFORMATINVALID = 'InvalidParameterValue.ConfigValueFormatInvalid'
 
@@ -467,15 +632,15 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPAPPLICATIONIDNULL = 'InvalidParameterValue.C
 # 集群 CPU 资源不足。
 INVALIDPARAMETERVALUE_CONTAINERGROUPCPULIMITOVER = 'InvalidParameterValue.ContainergroupCpulimitOver'
 
-# 容器 Env 的 Value 和 ValueFrom 至少要有一个。
-INVALIDPARAMETERVALUE_CONTAINERGROUPENVVALUENOTSET = 'InvalidParameterValue.ContainergroupEnvValueNotSet'
-
 # 部署组ID不能为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPIDNULL = 'InvalidParameterValue.ContainergroupGroupidNull'
 
 # 部署组名不能大于60个字符。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPNAMELEGNTH = 'InvalidParameterValue.ContainergroupGroupnameLegnth'
 
+# 部署组名不能为空。
+INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPNAMENULL = 'InvalidParameterValue.ContainergroupGroupnameNull'
+
 # 部署组名称格式不正确,只能包含小写字母、数字及分隔符("-"),且必须以小写字母开头，数字或小写字母结尾。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPNAMEREGEXMATCHFALSE = 'InvalidParameterValue.ContainergroupGroupnameRegexMatchFalse'
 
@@ -506,6 +671,12 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPPORTSREPEAT = 'InvalidParameterValue.Contain
 # 协议值非法,限定:TCP/UDP。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLINVALID = 'InvalidParameterValue.ContainergroupProtocolInvalid'
 
+# 公网访问方式下，协议需要一致。
+INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLMIXERROR = 'InvalidParameterValue.ContainergroupProtocolMixError'
+
+# 协议不能为空。
+INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLNULL = 'InvalidParameterValue.ContainergroupProtocolNull'
+
 # 协议端口不能为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLPORTSNULL = 'InvalidParameterValue.ContainergroupProtocolPortsNull'
 
@@ -554,6 +725,9 @@ INVALIDPARAMETERVALUE_FILECONFIGEXISTSPATH = 'InvalidParameterValue.FileConfigEx
 # 其他用户已发布此配置文件路径。
 INVALIDPARAMETERVALUE_FILECONFIGEXISTSPATHOTHER = 'InvalidParameterValue.FileConfigExistsPathOther'
 
+# 文件配置项文件名称不合规。
+INVALIDPARAMETERVALUE_FILECONFIGFILENAMEINVALID = 'InvalidParameterValue.FileConfigFileNameInvalid'
+
 # 文件配置项文件路径不合规。
 INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileConfigFilePathInvalid'
 
@@ -566,6 +740,9 @@ INVALIDPARAMETERVALUE_FILECONFIGNOTEXISTSORPERMISSIONDENIED = 'InvalidParameterV
 # 同一部署组禁止配置文件重复(文件路径+文件名)。
 INVALIDPARAMETERVALUE_FILECONFIGPATHEXISTS = 'InvalidParameterValue.FileConfigPathExists'
 
+# 无法获取文件配置项发布信息。
+INVALIDPARAMETERVALUE_FILECONFIGRELEASENOTEXISTS = 'InvalidParameterValue.FileConfigReleaseNotExists'
+
 # 文件配置项版本描述不合规。
 INVALIDPARAMETERVALUE_FILECONFIGVERSIONDESCINVALID = 'InvalidParameterValue.FileConfigVersionDescInvalid'
 
@@ -614,12 +791,12 @@ INVALIDPARAMETERVALUE_GROUPSTATUSINVALID = 'InvalidParameterValue.GroupStatusInv
 # 分组操作，无有效机器。
 INVALIDPARAMETERVALUE_GROUPVALIDINSTANCENULL = 'InvalidParameterValue.GroupValidInstanceNull'
 
+# 镜像仓库名不能为空。
+INVALIDPARAMETERVALUE_IMAGEREPOREPONAMENULL = 'InvalidParameterValue.ImagerepoRepoNameNull'
+
 # 镜像仓库名不合法,示例:tsf-repo/nginx。
 INVALIDPARAMETERVALUE_IMAGEREPOREPONAMEINVALID = 'InvalidParameterValue.ImagerepoReponameInvalid'
 
-# 镜像仓库名不能为空。
-INVALIDPARAMETERVALUE_IMAGEREPOREPONAMENULL = 'InvalidParameterValue.ImagerepoReponameNull'
-
 # imageTags不能为空。
 INVALIDPARAMETERVALUE_IMAGEREPOTAGNAMENULL = 'InvalidParameterValue.ImagerepoTagnameNull'
 
@@ -710,6 +887,9 @@ INVALIDPARAMETERVALUE_NAMESPACENOTEXISTS = 'InvalidParameterValue.NamespaceNotEx
 # 配置项已经发布，不允许删除。
 INVALIDPARAMETERVALUE_RELEASEDCONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedConfigCanNotBeDeleted'
 
+# 文件配置项已经发布，不允许删除。
+INVALIDPARAMETERVALUE_RELEASEDFILECONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedFileConfigCanNotBeDeleted'
+
 # 无权限操作资源%s。
 INVALIDPARAMETERVALUE_RESOURCEPERMISSIONDENIED = 'InvalidParameterValue.ResourcePermissionDenied'
 
@@ -728,6 +908,9 @@ INVALIDPARAMETERVALUE_SERVICENOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValu
 # 无效请求参数。
 INVALIDPARAMETERVALUE_TASKPARAMETERINVALID = 'InvalidParameterValue.TaskParameterInvalid'
 
+# 仅有停止状态下的部署组才可以不启动。
+INVALIDPARAMETERVALUE_WRONGDONTSTARTVALUE = 'InvalidParameterValue.WrongDontStartValue'
+
 # 命名空间数达到上限。
 LIMITEXCEEDED_ERRNAMESPACEMAXLIMIT = 'LimitExceeded.ErrNamespaceMaxLimit'
 
@@ -746,6 +929,9 @@ MISSINGPARAMETER_APPLICATIONIDREQUIRED = 'MissingParameter.ApplicationIdRequired
 # 应用类型不能为空。
 MISSINGPARAMETER_APPLICATIONTYPENULL = 'MissingParameter.ApplicationTypeNull'
 
+# 集群ID未填写。
+MISSINGPARAMETER_CLUSTERIDREQUIRED = 'MissingParameter.ClusterIdRequired'
+
 # 集群所属子网不能为空。
 MISSINGPARAMETER_CLUSTERSUBNETREQUIRED = 'MissingParameter.ClusterSubnetRequired'
 
@@ -758,6 +944,15 @@ MISSINGPARAMETER_CONFIGNAMEREQUIRED = 'MissingParameter.ConfigNameRequired'
 # 配置项发布信息ID未填写。
 MISSINGPARAMETER_CONFIGRELEASEIDREQUIRED = 'MissingParameter.ConfigReleaseIdRequired'
 
+# 缺少配置模板id。
+MISSINGPARAMETER_CONFIGTEMPLATEIDREQUIRED = 'MissingParameter.ConfigTemplateIdRequired'
+
+# 配置模板名称未填写。
+MISSINGPARAMETER_CONFIGTEMPLATENAMEREQUIRED = 'MissingParameter.ConfigTemplateNameRequired'
+
+# 配置模板类型未填写。
+MISSINGPARAMETER_CONFIGTEMPLATETYPEREQUIRED = 'MissingParameter.ConfigTemplateTypeRequired'
+
 # 配置项类型未填写。
 MISSINGPARAMETER_CONFIGTYPEREQUIRED = 'MissingParameter.ConfigTypeRequired'
 
@@ -776,9 +971,24 @@ MISSINGPARAMETER_GATEWAYPARAMETERREQUIRED = 'MissingParameter.GatewayParameterRe
 # 分组所属应用不能为空。
 MISSINGPARAMETER_GROUPAPPLICATIONNULL = 'MissingParameter.GroupApplicationNull'
 
+# 分组扩容操作，机器列表为空。
+MISSINGPARAMETER_GROUPEXPANDSERVERIDNULL = 'MissingParameter.GroupExpandServeridNull'
+
 # 分组ID不能为空。
 MISSINGPARAMETER_GROUPIDNULL = 'MissingParameter.GroupIdNull'
 
+# 部署组ID未填写。
+MISSINGPARAMETER_GROUPIDREQUIRED = 'MissingParameter.GroupIdRequired'
+
+# 分组所属命名空间不能为空。
+MISSINGPARAMETER_GROUPNAMESPACENULL = 'MissingParameter.GroupNamespaceNull'
+
+# 分组缩容操作，机器列表为空。
+MISSINGPARAMETER_GROUPSHIRKSERVERIDNULL = 'MissingParameter.GroupShirkServeridNull'
+
+# 虚拟机集群导入云主机导入方式为空。
+MISSINGPARAMETER_INSTANCEIMPORTMODENULL = 'MissingParameter.InstanceImportModeNull'
+
 # 命名空间ID不能为空。
 MISSINGPARAMETER_NAMESPACEIDREQUIRED = 'MissingParameter.NamespaceIdRequired'
 
@@ -788,6 +998,9 @@ MISSINGPARAMETER_REQUIREDPARAMETERMISSING = 'MissingParameter.RequiredParameterM
 # 未填写服务Id。
 MISSINGPARAMETER_SERVICEIDREQUIRED = 'MissingParameter.ServiceIdRequired'
 
+# 未指定%s。。
+MISSINGPARAMETER_SYSTEMPARAMETERREQUIRED = 'MissingParameter.SystemParameterRequired'
+
 # 缺少必填参数。
 MISSINGPARAMETER_TASKPARAMETERMISSED = 'MissingParameter.TaskParameterMissed'
 
@@ -803,15 +1016,24 @@ RESOURCEINUSE_DEFAULTNAMEPSACECANNOTBEDELETED = 'ResourceInUse.DefaultNamepsaceC
 # 此分组下存在资源，无法执行删除操作。
 RESOURCEINUSE_GROUPCANNOTDELETE = 'ResourceInUse.GroupCannotDelete'
 
+# 集群下存在分组。
+RESOURCEINUSE_GROUPEXISTS = 'ResourceInUse.GroupExists'
+
 # 部署组在更新中 请稍后再执行该操作。
 RESOURCEINUSE_GROUPINOPERATION = 'ResourceInUse.GroupInOperation'
 
+# 实例已经存在。
+RESOURCEINUSE_INSTANCEEXISTS = 'ResourceInUse.InstanceExists'
+
 # 机器实例已经被使用。
 RESOURCEINUSE_INSTANCEHASBEENUSED = 'ResourceInUse.InstanceHasBeenUsed'
 
 # 此命名空间下存在资源，无法执行删除操作。
 RESOURCEINUSE_NAMESPACECANNOTDELETE = 'ResourceInUse.NamespaceCannotDelete'
 
+# 集群下存在非默认命名空间。
+RESOURCEINUSE_NONDEFAULTNAMESPACEEXISTS = 'ResourceInUse.NonDefaultNamespaceExists'
+
 # 资源对象已存在。
 RESOURCEINUSE_OBJECTEXIST = 'ResourceInUse.ObjectExist'
 
@@ -824,7 +1046,7 @@ RESOURCEINSUFFICIENT_PACKAGESPACEFULL = 'ResourceInsufficient.PackageSpaceFull'
 # 无法获取应用信息。
 RESOURCENOTFOUND_APPLICATIONNOTEXIST = 'ResourceNotFound.ApplicationNotExist'
 
-# 应用不存在或应用不属于当前项目。
+# 无法获取应用或应用不属于当前项目。
 RESOURCENOTFOUND_APPLICATIONPROJECTNOTMATCH = 'ResourceNotFound.ApplicationProjectNotMatch'
 
 # 无法获取命名空间所属集群。
@@ -863,6 +1085,9 @@ RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'
 # 无法获取机器信息。
 RESOURCENOTFOUND_INSTANCENOTEXIST = 'ResourceNotFound.InstanceNotExist'
 
+# [%s]模块未提供该接口[%s]。。
+RESOURCENOTFOUND_INTERFACENOTFOUND = 'ResourceNotFound.InterfaceNotFound'
+
 # 无法找到License服务器。
 RESOURCENOTFOUND_LICENSESERVERNOTFOUND = 'ResourceNotFound.LicenseServerNotFound'
 
